@@ -1,11 +1,10 @@
 ; -*- Lisp -*-
 (in-package :maxima)
 
-(defparameter *autoconf-variables-set* "@variables_set@")
 (defparameter *autoconf-prefix* "/usr")
 (defparameter *autoconf-exec_prefix* "/usr")
 (defparameter *autoconf-package* "maxima")
-(defparameter *autoconf-version* "5.42.2")
+(defparameter *autoconf-version* "5.43.0")
 (defparameter *autoconf-libdir* "/usr/lib")
 (defparameter *autoconf-libexecdir* "/usr/lib")
 (defparameter *autoconf-datadir* "/usr/share")
@@ -16,10 +15,10 @@
 ;; But at least until dec 2015 we didn't need to check for a specific windows flavour.
 (defparameter *autoconf-win32* "false")
 (defparameter *autoconf-windows* "false")
-(defparameter *autoconf-ld-flags* "-Wl,-O1,--sort-common,--as-needed,-z,relro")
+(defparameter *autoconf-ld-flags* "-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now")
 
 ;; This will be T if this was a lisp-only build
-(defparameter *autoconf-lisp-only-build* (eq t '@lisp_only_build@))
+(defparameter *autoconf-lisp-only-build* (eq t 'nil))
  
-(defparameter *maxima-source-root* "/builds/chakra/packages/desktop/maxima/src/maxima-5.42.2")
+(defparameter *maxima-source-root* "/build/maxima/src/maxima-5.43.0")
 (defparameter *maxima-default-layout-autotools* "true")
